@@ -76,6 +76,7 @@ def check_access_rights(service: str,
             else:
                 claims = {}
                 token = str(request.headers.get('Authorization', '')).split(' ').pop()
+                origin = str(request.headers.get('origin', ''))
                 try:
                     claims = firebase_auth.verify_id_token(token)
                 except (firebase_auth.ExpiredIdTokenError,
@@ -87,7 +88,7 @@ def check_access_rights(service: str,
                     return {'detail': str(e)}, 401
 
                 try:
-                    send_tracking_information(claims['email'], service, job_func.__name__, project,
+                    send_tracking_information(claims['email'], service, job_func.__name__, origin, project,
                                               pubsub_client, datastore_client)
                 except KeyError:
                     adscale_log(ServiceEnum.TRACKING, f'The user email is not contained in the claims')
